==========
Evil Alien
==========

Somewhere beneath you, in deepest, blackest space, works Elron, the Evil Alien. You've managed to deactivate all but his short-range weapons, but he can still make his ship invisible. You know he's somewhere within the three-dimensional grid you can see on your ship screen, but where?

You have four space bombs. Each one can be exploded at a position in the grid specified by three numbers between 0 and 9. Can you blast the Evil Elron out of space before he creeps up and captures you?


The code
========

.. literalinclude:: evil_alien.py
   :language: python
